@@ -14,19 +14,21 @@ details.
 
 You should have received a copy of the GNU General Public License along with 
 JOE; see the file COPYING.  If not, write to the Free Software Foundation, 
-675 Mass Ave, Cambridge, MA 02139, USA.  */ 
+675 Mass Ave, Cambridge, MA 02139, USA.  */
 
 #ifndef _Imain
 #define _Imain 1
 
 #include "config.h"
+
 #include "w.h"
 
 extern char *exmsg;		/* Exit message */
 extern int help;		/* Set to start with help on */
 extern SCREEN *maint;		/* Primary screen */
-void nungetc();
-void dofollows();
-int edloop();
+void nungetc PARAMS((int c));
+void dofollows PARAMS((void));
+int edloop PARAMS((int flg));
+void edupd PARAMS((int flg));
 
 #endif
