@@ -14,11 +14,13 @@ details.
 
 You should have received a copy of the GNU General Public License along with 
 JOE; see the file COPYING.  If not, write to the Free Software Foundation, 
-675 Mass Ave, Cambridge, MA 02139, USA.  */ 
+675 Mass Ave, Cambridge, MA 02139, USA.  */
 
 #ifndef _Iregex
 #define _Iregex 1
 
-int pmatch();
+#include "config.h"
+
+int pmatch PARAMS((char **pieces, char *regex, int len, P *p, int n, int icase));
 
 #endif
