@@ -14,7 +14,7 @@ details.
 
 You should have received a copy of the GNU General Public License along with 
 JOE; see the file COPYING.  If not, write to the Free Software Foundation, 
-675 Mass Ave, Cambridge, MA 02139, USA.  */ 
+675 Mass Ave, Cambridge, MA 02139, USA.  */
 
 #ifndef _Itw
 #define _Itw 1
@@ -25,29 +25,26 @@ JOE; see the file COPYING.  If not, write to the Free Software Foundation,
 
 typedef struct tw TW;
 
-struct tw
- {
- /* Status line info */
- char *stalin;
- char *staright;
- int staon;				/* Set if status line was on */
- long prevline;				/* Previous cursor line number */
- int changed;				/* Previous changed value */
- };
+struct tw {
+	/* Status line info */
+	char *stalin;
+	char *staright;
+	int staon;		/* Set if status line was on */
+	long prevline;		/* Previous cursor line number */
+	int changed;		/* Previous changed value */
+};
 
 #define TYPETW 0x100
 
-/* BW *wmktw(SCREEN *t,B *b)
- */
-BW *wmktw();
+BW *wmktw PARAMS((SCREEN *t, B *b));
 
-int usplitw();
-int uduptw();
-int utw0();
-int utw1();
-int uabortbuf();
-int uabort();
-void setline();
+int usplitw PARAMS((BW *bw));
+int uduptw PARAMS((BW *bw));
+int utw0 PARAMS((BASE *b));
+int utw1 PARAMS((BASE *b));
+int uabortbuf PARAMS((BW *bw));
+int uabort PARAMS((BW *bw, int k));
+void setline PARAMS((B *b, long int line));
 
 extern int staen;
 
