@@ -3,13 +3,14 @@
 	Copyright (C) 1992 Joseph H. Allen
 
 	This file is part of JOE (Joe's Own Editor)
-*/ 
+*/
 
 #ifndef _Iushell
 #define _Iushell 1
+#include "bw.h"
 
-int ubknd();
-int urun();
-int ukillpid();
+int ubknd(BW * bw);
+int ukillpid(BW * bw);
+int urun(BW * bw);
 
 #endif
