@@ -6,19 +6,19 @@
 		(C) 2001 Marek 'Marx' Grac
 
 	This file is part of JOE (Joe's Own Editor)
-*/ 
+*/
 
 #ifndef _JOEutils
 #define _JOEutils 1
 
-#include <ctype.h>
+#include "config.h"
 
 /* 
  * Characters which are considered as word characters 
  * 	_ is considered as word character because is often used 
  *	in the names of C/C++ functions
  */
-#define isalnum_(c) (isalnum(c) || (c==*"_"))
+unsigned int isalnum_ PARAMS((unsigned int c));
 
 /* 
  * Whitespace characters are characters like tab, space, ...
@@ -27,14 +27,22 @@
  *	This is because I don't want to be forced to end 
  *	*rc file with \n
  */
-#define isspace_eof(c) (isspace(c) || (!c))
+int isspace_eof PARAMS((int c));
+
+/*
+ * Define function isblank(c)
+ *	isblank() is GNU extension;
+ *	even #including <ctype.h> without additional hackery doesn't import
+ *	the prototype, so we define it here unconditionaly
+ */
+int isblank PARAMS((int c));
 
 /*
  * Functions which return minimum/maximum of two numbers  
  */
-unsigned uns_min (unsigned a, unsigned b);
-int int_min (int a, int b);
-long long_max (long a, long b);
-long long_min (long a, long b);
+unsigned int uns_min PARAMS((unsigned int a, unsigned int b));
+signed int int_min PARAMS((signed int a, int signed b));
+signed long long_max PARAMS((signed long a, signed long b));
+signed long long_min PARAMS((signed long a, signed long b));
 
-#endif
\ No newline at end of file
+#endif
